Product class

Inheritance
Mixed-in types

Constructors

Product({int? id, required String name, required double price, required String description})

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
id int?
finalinherited
name String
final
price double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
no setteroverride

Methods

copyWith({int? id, String? name, double? price, String? description}) Product
override
create(Product item) Future<Product>
inherited
delete(int id) Future<int>
inherited
fromMap(Map<String, dynamic> map) Product
override
initDb() Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(int id) Future<Product?>
inherited
readAll() Future<List<Product>>
inherited
toMap(Product item) Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
update(Product item) Future<int>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited