User class

Inheritance
Mixed-in types

Constructors

User({int? id, required String name, required int age})

Properties

age int
final
hashCode int
The hash code for this object.
no setterinherited
id int?
finalinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
no setteroverride

Methods

copyWith({int? id, String? name, int? age}) User
override
create(User item) Future<User>
inherited
delete(int id) Future<int>
inherited
fromMap(Map<String, dynamic> map) User
override
initDb() Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(int id) Future<User?>
inherited
readAll() Future<List<User>>
inherited
toMap(User item) Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
update(User item) Future<int>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited