Convertible class abstract
@Author: DavidZou @GitHub: https://github.com/davidzou @Email: wearecisco@gmail.com @Date: 2022/6/29 @Description: 定义可转换的表数据对象接口。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - 将对象转换为一个映射(Map),用于存储到数据库。
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited